## ---- echo=FALSE, results="hide"----------------------------------------------
options("knitr.graphics.auto_pdf"=TRUE)

## ---- eval=FALSE--------------------------------------------------------------
#  options(reticulate.useImportHook=FALSE)

## -----------------------------------------------------------------------------
library(crisprScore)
data(scoringMethodsInfo)
print(scoringMethodsInfo)

## ---- echo=FALSE,fig.cap="Sequence inputs for Cas9 scoring methods"-----------
knitr::include_graphics("./figures/sequences_cas9.svg")

## ---- echo=FALSE, fig.cap="Sequence inputs for Cas12a scoring methods"--------
knitr::include_graphics("./figures/sequences_cas12a.svg")

## ---- eval=TRUE---------------------------------------------------------------
flank5 <- "ACCT" #4bp
spacer <- "ATCGATGCTGATGCTAGATA" #20bp
pam    <- "AGG" #3bp 
flank3 <- "TTG" #3bp
input  <- paste0(flank5, spacer, pam, flank3) 
results <- getRuleSet1Scores(input)

## ---- eval=FALSE--------------------------------------------------------------
#  flank5 <- "ACCT" #4bp
#  spacer <- "ATCGATGCTGATGCTAGATA" #20bp
#  pam    <- "AGG" #3bp
#  flank3 <- "TTG" #3bp
#  input  <- paste0(flank5, spacer, pam, flank3)
#  results <- getAzimuthScores(input)

## ---- eval=FALSE--------------------------------------------------------------
#  spacer  <- "ATCGATGCTGATGCTAGATA" #20bp
#  pam     <- "AGG" #3bp
#  input   <- paste0(spacer, pam)
#  results <- getDeepHFScores(input)

## ---- eval=FALSE--------------------------------------------------------------
#  flank5 <- "ACC" #3bp
#  pam    <- "TTTT" #4bp
#  spacer <- "AATCGATGCTGATGCTAGATATT" #23bp
#  flank3 <- "AAGT" #4bp
#  input  <- paste0(flank5, pam, spacer, flank3)
#  results <- getDeepCpf1Scores(input)

## ---- eval=FALSE--------------------------------------------------------------
#  flank5 <- "ACC" #3bp
#  pam    <- "TTTT" #4bp
#  spacer <- "AATCGATGCTGATGCTAGATATT" #23bp
#  flank3 <- "AAGT" #4bp
#  input  <- paste0(flank5, pam, spacer, flank3)
#  results <- getEnPAMGBScores(input)

## ---- eval=TRUE---------------------------------------------------------------
flank5 <- "ACCTAA" #6bp
spacer <- "ATCGATGCTGATGCTAGATA" #20bp
pam    <- "AGG" #3bp 
flank3 <- "TTGAAT" #6bp
input  <- paste0(flank5, spacer, pam, flank3) 
results <- getCRISPRscanScores(input)

## -----------------------------------------------------------------------------
spacer   <- "ATCGATGCTGATGCTAGATA"
protospacers  <- c("ACCGATGCTGATGCTAGATA",
                   "ATCGATGCTGATGCTAGATT",
                   "ATCGATGCTGATGCTAGATA")
pams <- c("AGG", "AGG", "AGA")
getMITScores(spacers=spacer,
             protospacers=protospacers,
             pams=pams)

## -----------------------------------------------------------------------------
spacer   <- "ATCGATGCTGATGCTAGATA"
protospacers  <- c("ACCGATGCTGATGCTAGATA",
                   "ATCGATGCTGATGCTAGATT",
                   "ATCGATGCTGATGCTAGATA")
pams <- c("AGG", "AGG", "AGA")
getCFDScores(spacers=spacer,
             protospacers=protospacers,
             pams=pams)

## ---- eval=FALSE--------------------------------------------------------------
#  flank5 <- "ACCTTTTAATCGA" #13bp
#  spacer <- "TGCTGATGCTAGATATTAAG" #20bp
#  pam    <- "TGG" #3bp
#  flank3 <- "CTTTTAATCGATGCTGATGCTAGATATTA" #29bp
#  input <- paste0(flank5, spacer, pam, flank3)
#  results <- getLindelScores(input)

## -----------------------------------------------------------------------------
sessionInfo()

